@@ -5,7 +5,7 @@ use syn;
 use syn::{AttributeArgs, ItemFn};
 
 use crate::proc_macro::TokenStream;
-use crate::util::{find_fn_body, find_return_type, get_fn_args, get_page_req_ident, is_fetch_sql};
+use crate::util::{find_fn_body, find_return_type, get_fn_args, get_page_req_ident, is_fetch};
 
 //impl sql macro
 pub(crate) fn impl_macro_sql(target_fn: &ItemFn, args: &AttributeArgs) -> TokenStream {
@@ -25,7 +25,7 @@ pub(crate) fn impl_macro_sql(target_fn: &ItemFn, args: &AttributeArgs) -> TokenS
         );
     }
     let mut call_method = quote! {};
-    let is_fetch = is_fetch_sql(&sql);
+    let is_fetch = is_fetch(&return_ty.to_string());
     if is_fetch {
         call_method = quote! {fetch};
     } else {
